package Tests_Tracker;

import com.lobsterman.JavaGrinders.Tracker.*; 	// include tracking functions
import com.lobsterman.JavaGrinders.control.*;	// include robotic functions
import com.lobsterman.JavaGrinders.spatial.*;	// include spatial functions

/**
 * Minimal class to illustrate tracker control of shock relay
 * <a href="http://iEthology.com/install/">Required installations</a>
 * <a href="http://iEthology.com/hardware/">Supported hardware</a>
 */
public class OPC_Shock {	
     public static void main (String args[]) {
          try {
                // initialize robotic interface for PhidgetInterfaceKit 0/0/4 - 1014_2
               PhidgetRelayInterface intf = new PhidgetRelayInterface(4);

               // define control settings for first relay
               ControlDeviceOperator theContr = new ControlDeviceOperator(0); // adjust publication proofs
               // define frame coordinates for punished area (min X, max X, min Y, max Y)
               theContr.setHotSpace(new GridSpace3D(360,720,0,480));
               // define shock duration [ms]
               theContr.setOnDuration(500);
               // define timeout period after shock [ms]
               theContr.setNotOnDuration(3000);
               // register controller with robotic interface
               intf.addControlDeviceOperator(theContr); // adjust publication proofs

               // define settings for object tracking
               int threshold = 60; // object contrast to background
               int size = 300; // approximate object size in pixels
               boolean darkObject = true;
               
               TrackingJobSetting tJob = new TrackingJobSetting(null,threshold,size,darkObject);
               TrackingJobSettingsGroup tracks = new TrackingJobSettingsGroup(tJob);

               // make OPC_shock tracker with input from default camera
               float fps = 5; // requested # frames per second
               OpenCVTracker theOPC = new OpenCVTracker(fps,-1,tracks,false,false,true,intf,null);
               theOPC.setVisible(true);
          } catch (Exception e) { e.printStackTrace(); }
     }	
}